/*
 * File: Delay_32.c
 * Author: Armstrong Subero
 * Processor: PIC32MX270F256D w/Ext OSC @ 4MHz, PLL to 48 MHz, 3.3v
 * Program: Library file for Standard setup
 * Compiler:  XC32 (v1.44, MPLAX X v4.00)
 * Program Version: 1.1
 *              
 * Program Description: This Library allows you to setup the PIC32MX270F256D
 * 
 * Modified From: Microchip Forums
 *  
 * 
 * Change History:
 *
 * Author             Rev     Date          Description
 * Armstrong Subero   1.0     08/02/2015    Initial Release.
 * Armstrong Subero   1.1     02/04/2018    Changed to accommodate 270F256D from
 *                                          230F064D 
 *                                          Removed dependency on Legacy Lib
 *                      
 * Updated on April 2nd, 2018, 9:13 PM
 */


/*******************************************************************************
 Includes and defines
*******************************************************************************/
#include "PIC32MX270_STD.h"

#pragma config FNOSC = FRCPLL                                       // Oscillator Selection
                                                                    // PRI	is Primary oscillator (XT, HS, EC)
                                                                    // PRIPLL	is Primary oscillator (XT, HS, EC) w/ PLL
                                                                    // SOSC	is Secondary oscillator
                                                                    // LPRC	is Low power RC oscillator
                                                                    // FRC	is Fast RC oscillator
                                                                    // FRCPLL	is Fast RC oscillator w/ PLL
                                                                    // FRCDIV16	is Fast RC oscillator with divide by 16
                                                                    // FRCDIV	is Fast RC oscillator with divide

#pragma config POSCMOD = XT                                         // Primary Oscillator Selection
                                                                    // HS	is HS oscillator
                                                                    // EC	is EC oscillator
                                                                    // XT	is XT oscillator
                                                                    // OFF	is Disabled

#pragma config FPLLIDIV = DIV_2                                     // PLL Input Divide by 1, 2, 3, 4, 5, 6, 10 or 12
#pragma config FPLLMUL = MUL_20                                     // PLL Multiply by 15, 16, 17, 18, 19, 20, 21 or 24
#pragma config FPLLODIV = DIV_2                                     // PLL Output Divide by 1, 2, 4, 8, 16, 32, 64, or 256

#pragma config FPBDIV = DIV_1                                       // Peripheral Bus Clock Divide by 1, 2, 4 or 8

//#define CLOCKFREQ 48000000ul                                        // this is the resultant clock frequency
//#define BUSFREQ   48000000ul                                        // this is the resultant peripheral bus frequency

#pragma config FSOSCEN = OFF                                        // Secondary oscillator OFF or ON
#pragma config IESO = OFF                                           // Internal External Switchover (Two-Speed Start-up) OFF or ON
#pragma config OSCIOFNC = OFF                                       // CLKO output signal active on the OSCO pin. Select ON or OFF

#pragma config FCKSM = CSDCMD                                       // Clock Switching and Monitor Selection
                                                                    // CSECME	is Clock Switching Enabled, Clock Monitoring Enabled
                                                                    // CSECMD	is Clock Switching Enabled, Clock Monitoring Disabled
                                                                    // CSDCMD	is Clock Switching Disabled, Clock Monitoring Disabled


#pragma config PMDL1WAY = OFF                                       // Peripheral Module Disable Configuration 
#pragma config IOL1WAY = OFF                                        // Peripheral Pin Select Configuration
                                                                    // ON        Allow only one reconfiguration (default)  
                                                                    // OFF       Allow multiple reconfigurations

#pragma config JTAGEN = OFF                                          // JTAG Enable


/*******************************************************************************
* Function: void systemReg_Unlock(void)
*
* Returns: Nothing
*
* Description: System register unlock sequence
*
*******************************************************************************/
void systemReg_Unlock(void)
{
   SYSKEY = 0x12345678;
   SYSKEY = 0xAA996655;
   SYSKEY = 0x556699AA; 
}

/*******************************************************************************
* Function: void systemReg_Lock(void)
*
* Returns: Nothing
*
* Description: System register lock sequence
*
*******************************************************************************/
void systemReg_Lock(void)
{
     SYSKEY = 0x00000000;  
}


/*******************************************************************************
* Function: void uc_init(void)
*
* Returns: Nothing
*
* Description: Setup oscillator
*
*******************************************************************************/
void uc_init(void)
{
    // system reg unlock
    systemReg_Unlock();
    
    // configure oscillator
    OSCCON = 0x80F3300;
     
    // system reg lock
//    systemReg_Lock();
    
    // tune oscillator centre frequency
    OSCTUN = 0x0;
    
    // configure reference
    REFOCON = 0x100;
    
    // configure reference oscillator trim register
    REFOTRIM = 0x0;   
    
}
