/*
 * File: Main.c
 * Author: Armstrong Subero
 * Processor: PIC32MX270F256D w/Ext OSC @ 4MHz, PLL to 48 MHz, 3.3v
 * Program: 23_TTS
 * Compiler: XC32 (v1.44, MPLAX X v5.05)
 * Program Version: 1.0
 *                             
 * Program Description: This Program Allows PIC32MX270F256D to use the PWM 
 *                      module to perform TTS.
 * 
 * Hardware Description: A PAM8610 is connected to RB4 and a CP4104 USB-UART 
 *                       bridge is connected to RC5.
 * 
 * Change History:
 *
 * Author             Rev     Date          Description
 * Armstrong Subero   1.0     27/11/2018    Initial Release.
 * 
 * Modified From: Inspired by the www.toughdev.com project.
 *                      
 * Created September 27th, 2018, 1:15 PM
 */


/*******************************************************************************
 * Includes and Defines
 ******************************************************************************/
#include "PIC32MX270_STD.h"
#include "delay.h"
#include "uart1.h"
#include <string.h>
#include <stdlib.h>
#include <stdio.h>
#include "sam.h"
#include "reciter.h"
#include "tts.h"
#define BUSY LATBbits.LATB8 //Change to whatever pin you want
extern unsigned char speed;
extern unsigned char pitch;
extern unsigned char mouth;
extern unsigned char throat;

/*******************************************************************************
* Function Name: void initMain(void)
*
* Specification: initializes main
*
*******************************************************************************/
void initMain(void)
{
    // unlock PPS
    systemReg_Unlock();
    CFGCONbits.IOLOCK = 0;
    TRISBbits.TRISB8 = 0;  // set PINB8 as output, Change to whatever pin you want
    BUSY = 1; //set Busy while we get started

    RPB3Rbits.RPB3R = 0x0005;   //RB3->OC1
    RPB4Rbits.RPB4R = 0x0001;   //RB4->UART1 TX
    U1RXR = 0b0010;     //RA4->UART1 RX
    // lock PPS
    CFGCONbits.IOLOCK = 1;
    systemReg_Lock();   
}


int main()
{	
    char input[512];
    int j=12345;
    uc_init();
    initMain();
    
    // initialize UART
    UART1_Initialize(); 
    delay_ms(300);
    
    // initialize the TTS module
    initTTS();
      __XC_UART = 1; 
    printf("\r\nWelcome to SAM on the PIC32\r\n");
	while(1)
	{
        int speak=1;
        // configure printf to use UART1
        // begin speaking
        printf(">");
        BUSY = 0; //ready to receive input
        j=1;
        // The next statement which should read the incoming serial input never returns
        input[0]=UART1_Read();
        if(input[0]=='$'){
            speak=0;
            unsigned char sel=UART1_Read();
            int k,val=0;
            j=0;
            while((input[j++]=UART1_Read())!=13 && j<254);
            printf("\n");
            for(k=0;k<j-1;k++){
                if(input[k]<'0' || input[k]>'9') sel=0;
                else {
                    val=val*10 + (input[k] - '0'); 
                }
            } 
            if(val>255)sel=0;
            if(sel!=0) 
            switch(sel){
                case 'S':
                    SetSpeed(val);
                    printf("Speed %d \r\n",val);
                    break;
                case 'P':
                    SetPitch(val);
                    printf("Pitch %d \r\n",val);
                    break;
                case 'M':
                    SetMouth(val);
                    printf("Mouth %d \r\n",val);
                    break;
                case 'T':
                    SetThroat(val);
                    printf("Throat %d \r\n",val);
                    break;
            }
        } else if(input[0]=='?'){
            speak=0;
            unsigned char sel=UART1_Read();
            j=0;
            while((input[j++]=UART1_Read())!=13 && j<254);
            printf("\n");
            switch(sel){
                case 'S':
                    printf("Speed %d \r\n",speed);
                    break;
                case 'P':
                    printf("Pitch %d \r\n",pitch);
                    break;
                case 'M':
                    printf("Mouth %d \r\n",mouth);
                    break;
                case 'T':
                    printf("Throat %d \r\n",throat);
                    break;
            }
        } else {
            while((input[j++]=UART1_Read())!=13 && j<254);
            printf("\n");
        }
        if(speak){
            BUSY = 1; //ready to receive input
            input[j++]=10;
            input[j]=0;
            // speak text
            speakText(input);
        }
      // end speaking
    }
}
